/*
    Copyright 2004,2005,2006 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl.txt

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>



#define VER         "0.1"
#define BUFFSZ      4096
#define MAINPWD     "pw="
#define ACC         "POP3Account="
#define PASS        "POP3Password="



#ifndef WIN32
    #define strnicmp strncasecmp
#endif

#ifndef u_char
    #define u_char  unsigned char
#endif



void mpeek_pwd(u_char *pwd);
void std_err(void);



int main(int argc, char *argv[]) {
    FILE    *fd;
    u_char  *buff,
            *ptr;


    setbuf(stdout, NULL);

    fputs("\n"
        "Mailpeek passwords decoder "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(argc < 2) {
        printf("\nUsage: %s <Mailpeek.ini_OR_config.ini>\n"
            "\n"
            "Mailpeek.ini is located in the Windows folder and contains the access password\n"
            "config.ini instead is in the program folder and contains the account password\n"
            "\n", argv[0]);
        fputs("\n    Press RETURN to exit\n", stdout);
        fgetc(stdin);
        exit(1);
    }

    printf("\nOpening file %s\n\n", argv[1]);
    fd = fopen(argv[1], "rb");
    if(!fd) std_err();

    buff = malloc(BUFFSZ + 1);
    if(!buff) std_err();

    while(1) {
        if(!fgets(buff, BUFFSZ, fd)) break;

        if(!strnicmp(buff, MAINPWD, sizeof(MAINPWD) - 1)) {
            for(ptr = buff; *ptr > 0xd; ptr++);
            *ptr = 0;
            mpeek_pwd(buff + sizeof(MAINPWD) - 1);
            printf("%s\n", buff);
        } else if(!strnicmp(buff, ACC, sizeof(ACC) - 1)) {
            for(ptr = buff; *ptr > 0xd; ptr++);
            *ptr = 0;
            mpeek_pwd(buff + sizeof(ACC) - 1);
            printf("%s\n", buff);
        } else if(!strnicmp(buff, PASS, sizeof(PASS) - 1)) {
            for(ptr = buff; *ptr > 0xd; ptr++);
            *ptr = 0;
            mpeek_pwd(buff + sizeof(PASS) - 1);
            printf("%s\n", buff);
        }
    }

    fclose(fd);
    fputs("\n\n    Press RETURN to exit\n", stdout);
    fgetc(stdin);
    return(0);
}



void mpeek_pwd(u_char *pwd) {
    int     i;

    for(i = 0; *pwd; i++) {
        *pwd = *pwd + i - 5;
        pwd++;
    }
}



void std_err(void) {
    perror("\nError");
    fputs("\n    Press RETURN to exit\n", stdout);
    fgetc(stdin);
    exit(1);
}


